#!/bin/bash

set -euo pipefail

SCRIPT_DIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" &> /dev/null && pwd )"
HOST_WORKSPACE_PATH="${HOST_WORKSPACE_PATH:-$(pwd)}"

echo "--------------------------------"
echo "PWD:                 $(pwd)"
echo "SCRIPT_DIR:          $SCRIPT_DIR"
echo "GITHUB_WORKSPACE:    ${GITHUB_WORKSPACE:-not set}"
echo "HOST_WORKSPACE_PATH: $HOST_WORKSPACE_PATH"
echo "JOB_CONTAINER_NAME:  ${JOB_CONTAINER_NAME:-not set}"
echo "--------------------------------"
echo "--------------------------------"
echo "--------------------------------"
echo "Docker info:"
docker info | grep -E "(Docker Root Dir|Storage Driver)" || true
echo "Mount info:"
mount | grep -E "(overlay|workspace)" || true

echo "--------------------------------"
echo "--------------------------------"
echo "--------------------------------"
echo "ls on host"
ls -la ./

# Check if we're running in Gitea Actions
if [ -n "${JOB_CONTAINER_NAME:-}" ]; then
    echo "--------------------------------"
    echo "Running in Gitea Actions - using --volumes-from"
    echo "--------------------------------"
    
    echo "ls -la using --volumes-from"
    docker run --rm -i --entrypoint /bin/bash \
        --volumes-from="${JOB_CONTAINER_NAME}" \
        debian:latest -c "cd ${GITHUB_WORKSPACE} && ls -la"
    
    echo "--------------------------------"
    echo "Test file creation and reading"
    echo "Creating test file in action container..."
    echo "This is a test file from Gitea Actions" > test-file.txt
    
    echo "Reading test file from Docker container..."
    docker run --rm -i --entrypoint /bin/bash \
        --volumes-from="${JOB_CONTAINER_NAME}" \
        debian:latest -c "cd ${GITHUB_WORKSPACE} && cat test-file.txt"
    
    # Clean up
    rm -f test-file.txt
else
    echo "--------------------------------"
    echo "Running locally - no test."
    echo "--------------------------------"
fi


